==> guile-2.0.7.tar.xz: lib/guile/2.0/ccache/system/repl/debug.go <==
GOOF----LE-4-2.0,      ]  4  h\      ] g  guile	 	g  define-module*	 	 	g  system	g  repl	g  debug		 	
g  filenameS	f  system/repl/debug.scm	g  importsS	
g  base	g  pmatch	
 	 	g  syntax	
 	 	g  language	
 	 	g  vm	 	 	g  frame	 	 	g  ice-9	g  rdelim	 	  	!g  pretty-print	"! 	#" 	$g  format	%$ 	&% 	'g  inspect	(' 	)g  selectS	*g  %inspect	+'*	,+ 	-(), 	.g  program	/. 	0/ 	1 #&-0 
	2g  exportsS	3g  <debug>	4g  
make-debug	5g  debug?	6g  debug-frames	7g  debug-index	8g  debug-error-message	9g  debug-for-trap?	:g  terminal-width	;g  print-registers	<g  print-locals	=g  print-frame	>g  print-frames	?g  
frame->module	@g  
stack->vector	Ag  narrow-stack->vector	Bg  frame->stack-vector	C3456789:;<=>?@AB 	Dg  set-current-module	ED 	FD 	Gg  make-record-type	Hf  <debug>	Ig  frames	Jg  index	Kg  
error-message	Lg  	for-trap?	MIJKL 	Ng  record-predicate	Og  make-procedure-with-setter	Pg  record-accessor	Qg  record-modifier	Rg  
make-fluid	Sg  catch	TS 	US 	Vg  string->number	Wg  getenv	Xf  COLUMNS	Yg  integer?	Zg  exact?	[g  error	\f  -Expected a column number (a positive integer)	]g  make-hash-table	^g  
hash-for-each	_g  
hashq-set!	`g  	hashq-ref	ag  
reverse-hashq	bg  per-line-prefixS	cb		dc 	eg  current-output-port	ff    	gf  ~aRegisters:~%	hg  frame-instruction-pointer	ig  display	jg  run-hook	kg  before-print-hook	lf  ip = ~d
	mg  frame-stack-pointer	nf  
sp = #x~x
	og  
frame-address	pf  
fp = #x~x
	qg  widthS	rq		sb		trs 	ug  frame-bindings	vf  ~aNo local variables.~%	wf  ~aLocal variables:~%	xg  for-each	yg  frame-local-ref	zg  
binding:index	{g  binding:boxed?	|f  ~a~:[~; (boxed)~] = ~v:@y
	}g  binding:name	~g  indexS	~	 q	 g  full?S 	 g  last-sourceS 	 g  next-source?S 	   g  frame-next-source g  frame-source g  source:file f  
current input f  unknown file g  and=> g  source:line-for-user g  
source:column f  
~&In ~a:~& f  ~9@a~:[~*~3_~;~3d~] ~v:@y~% f  ~a:~a f    g  frame-call-representation f        	 g  forward?S 	 g  countS 	 g  	for-trap?S 	 r  g  
vector-length g  	positive? g  max g  min g  	negative? g  <= g  frame-procedure g  program? g  program-module g  current-module g  make-module g  module-use! g  
make-variable f  3~:[Read-only~;Mutable~] local variable ~a = ~70:@y
 g  module-add! g  stack-length g  make-vector g  frame-previous g  	stack-ref g  
make-stack    g  %stacksC 5       h     ]4	
12C5 4F >  "  G   4GiHM53R3        h      - 1 3   C        g  frames
			 g  index			 g  
error-message				 g  	for-trap?				 g   g333				  g  filenamef  system/repl/debug.scm
	9
 				
	  g  nameg  
make-debug C4R4Ni3i55R4Oi4Pi3iI54Qi3iI556R4Oi4Pi3iJ54Qi3iJ557R4Oi4Pi3iK54Qi3iK558R4Oi4Pi3iL54Qi3iL559R4Ri5  UVWX   h   h   ] 456   `       g  filenamef  system/repl/debug.scm
	E			E	8			E	@		E	8	
	E	( 		
   C      h   k   - 1 3 C     c       g  k
			 g  args			  g  filenamef  system/repl/debug.scm
	E	 			
   CYZ[\  h   :  )    ]3 L [  $   C45 4 5$  #4 5$   
$   "  "  "     $   C	HC] $  (4 5$  4 5$   
"  "  "  $  L  \C 6 2      g  t
		c g  w
	!	U g  t
	U	c g  w
	e   g  filenamef  system/repl/debug.scm
	B			D			E		!	E		$	F		.	F	
	/	F		9	F	
	=	F	*	A	F	
	U	D		e	B		k	I		l	I		v	I		w	I	) 	I	 	I	4 	I	 	I	 	K	 	K	 			c
 	e    C O  :R]^_`      h      ]L  4L 56        g  k
		 g  v		  g  filenamef  system/repl/debug.scm
	S			T	!		T	2		T	!		T			T	 			   C      h(      ]	45 4O  >  "  G  C          g  h
		% g  ret		%  g  filenamef  system/repl/debug.scm
	P
		Q	
		Q		
	R	 		%  g  nameg  
reverse-hashq CaRdef$ghijklmnop    h    - /   0   3 #  45 #  4>  "  G  4 54>  "  G  4	>  "  G  4
>  "  G  4 54>  "  G  4	>  "  G  4>  "  G  4
 54>  "  G  4	>  "  G  6       g  frame
	 g  port	 g  per-line-prefix		 g  val		G  g  val	   g  val	   g  filenamef  system/repl/debug.scm
	X
		X	1	(	Y	1	+	_		1	_		8	_		A	`		G	`		J	[		^	\		r	]		x	`				]	 	a	 	a	 	[	 	\	 	]	 	a		 	]	 	b	 	b	 	[	 	\		b			]	 	g  per-line-prefixS	   g  nameg  print-registers C;Rte:fu$vwxyz{ijk$|} 
hp      ]	4L 4 554 5$  "  4LL>  "  G  4>  "  G  L4	 54 5L6          g  binding
		m g  x		) g  v	)	m  g  filenamef  system/repl/debug.scm
	m			n			n	2		n			n			o			o		 	p		)	n			,	r		@	s		Y	t		Z	u		a	u	*	m	t	 		m   C   h   ]  - /   0   3 #  45 #  45 #  4 5(  
64>  "  G  	
 O 4 56  U      g  frame
		~ g  port		~ g  width			~ g  per-line-prefix			~ g  bindings		>	~  g  filenamef  system/repl/debug.scm
	d
		d	.	'	e	$	5	e	G	8	f		>	f		F	g		L	i		P	i		Q	k		W	k		^	k		v	v		~	l	 		~g  widthS	g  per-line-prefixS	   g  nameg  print-locals C<Re:$<qb  hH  '  - /   0   3 #  45 #  #  45 #  #  #  4$  "   5$  45$  "  "  4	
5	4	5
$  K$  45$  "  "  $  "  4
>  "  G  "   4	$  4	
5"  4 5>  "  G  $   6C          g  frame
	D g  port	D g  index		D g  width		D g  full?		D g  last-source		D g  next-source?		D g  source		dD g  t		s  g  file	 D g  line		 D g  col	
 D g  t	    
g  filenamef  system/repl/debug.scm
	x
		x	-	0	y	)	R			X			d			d			l	|		m	}		s	}	 	}	! 	~	 		  	 		  	 		  	 	|	 	}	 	}	 	}	! 	~	  	  	  	  	  	  	  	 	 	 	  	 	2 	& 	4 	@ 	(B 	 )	Dg  indexS	g  widthS	g  full?S	g  last-sourceS	g  next-source?S	   g  nameg  print-frame C=Re:=~q        h  X  - /   0   3 
#  45 #  45 #  #  #  #  4 5$  45"  $  
"  4
5"  $  
45"  "  $$  45$  "  ""  "	"  4	
	5$   
4




$  "  >  "  G  
$  "  	"  45"  %

$  $  45"  ""  "
"iC$  "  	
"P      P      g  frames
	z g  port	z g  width		z g  full?		z g  forward?		z g  count		z g  	for-trap?		z g  len		Xz g  	lower-idx	 z g  	upper-idx		 z g  i	
 c g  last-source	 c g  frame	 a  
g  filenamef  system/repl/debug.scm
 
	 	(	' 	$	R 		X 		` 		a 	(	l 		p 		v 		~ 	  	  	  	  	&  	  	  	#  	  	  	  	  	
  	  	  	
  	  	- 	(
 	 	% 	* 	4 	7 	< 	B 	C 	a 	c 	i 	z 	 +	zg  widthS	g  full?S	g  forward?S	g  countS	g  	for-trap?S	   g  nameg  print-frames C>Rxyz{$} 	 hp      ]4L 4 554 5$  "  4544 54 5$  "  >  "  G  L4 56          g  binding
		l g  x		l g  var		*	l  g  filenamef  system/repl/debug.scm
 		 		 	.	 		 	
	 		 		$ 	8	* 	
	- 		2 		3 		: 		C 		G 		J 	1	U 		b 	!	l 	 		l   Cu 
  hx   @  ]4 545$  ]45$  "  45 45 4>  "  G  4 O 4	 5>  "  G  C6  8      g  frame
		w g  proc			w g  t			3 g  mod		3	s g  mod*		:	s  g  filenamef  system/repl/debug.scm
 
	 			 		 		 		 		 		, 	.	3 		6 		: 		= 	
	Q 	
	] 		h 	
	w 	 		w  g  nameg  
frame->module C?R       hh   G  ]!4 54545$  ?"  &$  45""  
4 
5""   C       ?      g  stack
		a g  len			a g  v			a g  i		#	I g  frame		#	I  g  filenamef  system/repl/debug.scm
 
	 			 		 		 		 		 		# 		( 		, 	
	3 		6 		7 		E 		I 		K 		Z 	 		a  g  nameg  
stack->vector C@R@  h0      - 1 3 44 
5?$  6C              g  stack
			) g  args			) g  narrowed			)  g  filenamef  system/repl/debug.scm
 
	
 		
 	$	 		 		  		& 		( 	 				)
  g  nameg  narrow-stack->vector CARA      h8      ]	[$  	["  4 5

$  "  6              g  frame
		1 g  tag		1  g  filenamef  system/repl/debug.scm
 
	 		
 	
	 		 		 		) 		1 	 			1  g  nameg  frame->stack-vector CBRC       g  m
		, g  	set-width
  g  filenamef  system/repl/debug.scm		
	:	9
	A		A		@
	P
		X

 	d
	x
 
c 
2 
` 
~ 
 	
   C6 

==> guile-2.0.14.tar.xz: lib/guile/2.0/ccache/system/repl/debug.go <==
GOOF----LE-8-2.0a,      ]  4     h-      ] g  guile	 	g  define-module*	 	 	g  system	g  repl	g  debug		 	
g  filenameS	f  system/repl/debug.scm	g  importsS	
g  base	g  pmatch	
 	 	g  syntax	
 	 	g  language	
 	 	g  vm	 	 	g  frame	 	 	g  ice-9	g  rdelim	 	  	!g  pretty-print	"! 	#" 	$g  format	%$ 	&% 	'g  inspect	(' 	)g  selectS	*g  %inspect	+'*	,+ 	-(), 	.g  program	/. 	0/ 	1 #&-0 
	2g  exportsS	3g  <debug>	4g  
make-debug	5g  debug?	6g  debug-frames	7g  debug-index	8g  debug-error-message	9g  debug-for-trap?	:g  terminal-width	;g  print-registers	<g  print-locals	=g  print-frame	>g  print-frames	?g  
frame->module	@g  
stack->vector	Ag  narrow-stack->vector	Bg  frame->stack-vector	C3456789:;<=>?@AB 	Dg  set-current-module	ED 	FD 	Gg  make-record-type	Hf  <debug>	Ig  frames	Jg  index	Kg  
error-message	Lg  	for-trap?	MIJKL 	Ng  record-predicate	Og  make-procedure-with-setter	Pg  record-accessor	Qg  record-modifier	Rg  
make-fluid	Sg  catch	TS 	US 	Vg  string->number	Wg  getenv	Xf  COLUMNS	Yg  integer?	Zg  exact?	[g  error	\f  -Expected a column number (a positive integer)	]g  make-hash-table	^g  
hash-for-each	_g  
hashq-set!	`g  	hashq-ref	ag  
reverse-hashq	bg  per-line-prefixS	cb		dc 	eg  current-output-port	ff    	gf  ~aRegisters:~%	hg  frame-instruction-pointer	ig  display	jg  run-hook	kg  before-print-hook	lf  ip = ~d
	mg  frame-stack-pointer	nf  
sp = #x~x
	og  
frame-address	pf  
fp = #x~x
	qg  widthS	rq		sb		trs 	ug  frame-bindings	vf  ~aNo local variables.~%	wf  ~aLocal variables:~%	xg  for-each	yg  frame-local-ref	zg  
binding:index	{g  binding:boxed?	|f  ~a~:[~; (boxed)~] = ~v:@y
	}g  binding:name	~g  indexS	~	 q	 g  full?S 	 g  last-sourceS 	 g  next-source?S 	   g  frame-next-source g  frame-source g  source:file f  
current input f  unknown file g  and=> g  source:line-for-user g  
source:column f  
~&In ~a:~& f  ~9@a~:[~*~3_~;~3d~] ~v:@y~% f  ~a:~a f    g  frame-call-representation f        	 g  forward?S 	 g  countS 	 g  	for-trap?S 	 r  g  
vector-length g  max g  min g  frame-procedure g  program? g  program-module g  current-module g  make-module g  module-use! g  
make-variable f  3~:[Read-only~;Mutable~] local variable ~a = ~70:@y
 g  module-add! g  stack-length g  make-vector g  frame-previous g  	stack-ref g  
make-stack    g  %stacksC 5      hx     ]4	
12C5 4F >  "  G   4GiHM53R3        h      - 1 3   C        g  frames
			 g  index			 g  
error-message				 g  	for-trap?				 g  defrec-1f507eb13-0				  g  filenamef  system/repl/debug.scm
	9
 				
	  g  nameg  
make-debug C4R4Ni3i55R4Oi4Pi3iI54Qi3iI556R4Oi4Pi3iJ54Qi3iJ557R4Oi4Pi3iK54Qi3iK558R4Oi4Pi3iL54Qi3iL559R4Ri5  UVWX      h   h   ] 456   `       g  filenamef  system/repl/debug.scm
	E			E	8			E	@		E	8	
	E	( 		
   C      h   ]   -  1  3 C     U       g  args
			  g  filenamef  system/repl/debug.scm
	E	 			


   CYZ[\        h   :  )    ]3 L [  $   C45 4 5$  #4 5$   
$   "  "  "     $   C	HC] $  (4 5$  4 5$   
"  "  "  $  L  \C 6 2      g  t
		c g  w
	!	U g  t
	U	c g  w
	e   g  filenamef  system/repl/debug.scm
	B			D			E		!	E		$	F		.	F	
	/	F		9	F	
	=	F	*	A	F	
	U	D		e	B		k	I		l	I		v	I		w	I	) 	I	 	I	4 	I	 	I	 	K	 	K	 			c
 	e    C O  :R]^_`      h      ]L  4L 56        g  k
		 g  v		  g  filenamef  system/repl/debug.scm
	S			T	!		T	2		T	!		T			T	 			   C      h(      ]	45 4O  >  "  G  C          g  h
		% g  ret		%  g  filenamef  system/repl/debug.scm
	P
		Q	
		Q		
	R	 		%  g  nameg  
reverse-hashq CaRdef$ghijklmnop    h    - /   0   3 #  45 #  4>  "  G  4 54>  "  G  4	>  "  G  4
>  "  G  4 54>  "  G  4	>  "  G  4>  "  G  4
 54>  "  G  4	>  "  G  6       g  frame
	 g  port	 g  per-line-prefix		 g  val		G  g  val	   g  val	   g  filenamef  system/repl/debug.scm
	X
		X	1	(	Y	1	+	_		1	_		8	_		A	`		G	`		J	[		^	\		r	]		x	`				]	 	a	 	a	 	[	 	\	 	]	 	a		 	]	 	b	 	b	 	[	 	\		b			]	 	g  per-line-prefixS	   g  nameg  print-registers C;Rte:fu$vwxyz{ijk$|} 
hp      ]	4L 4 554 5$  "  4LL>  "  G  4>  "  G  L4	 54 5L6          g  binding
		m g  x		) g  v	)	m  g  filenamef  system/repl/debug.scm
	m			n			n	2		n			n			o			o		 	p		)	n			,	r		@	s		Y	t		Z	u		a	u	*	m	t	 		m   C   h   ]  - /   0   3 #  45 #  45 #  4 5(  
64>  "  G  	
 O 4 56  U      g  frame
		~ g  port		~ g  width			~ g  per-line-prefix			~ g  bindings		>	~  g  filenamef  system/repl/debug.scm
	d
		d	.	'	e	$	5	e	G	8	f		>	f		F	g		L	i		P	i		Q	k		W	k		^	k		v	v		~	l	 		~g  widthS	g  per-line-prefixS	   g  nameg  print-locals C<Re:$<qb  hH  '  - /   0   3 #  45 #  #  45 #  #  #  4$  "   5$  45$  "  "  4	
5	4	5
$  K$  45$  "  "  $  "  4
>  "  G  "   4	$  4	
5"  4 5>  "  G  $   6C          g  frame
	D g  port	D g  index		D g  width		D g  full?		D g  last-source		D g  next-source?		D g  source		dD g  t		s  g  file	 D g  line		 D g  col	
 D g  t	    
g  filenamef  system/repl/debug.scm
	x
		x	-	0	y	)	R			X			d			d			l	|		m	}		s	}	 	}	! 	~	 		  	 		  	 		  	 	|	 	}	 	}	 	}	! 	~	  	  	  	  	  	  	  	 	 	 	  	 	2 	& 	4 	@ 	(B 	 )	Dg  indexS	g  widthS	g  full?S	g  last-sourceS	g  next-source?S	   g  nameg  print-frame C=Re:=~q      h  _  - /   0   3 
#  45 #  45 #  #  #  #  4 5$  
"  $  
"  4
5"  $  
45"  "  !$  
$  "  ""  "	"  
$  
	$   
4
	


$  "  >  "  G  
$  "  	"  4
5"  %

$  $  45"  ""  "
"fCC$  "  	
"K       W      g  frames
	y g  port	y g  width		y g  full?		y g  forward?		y g  count		y g  	for-trap?		y g  len		Xy g  	lower-idx		}y g  	upper-idx		 y g  i	
 b g  last-source	 b g  frame	 ^  
g  filenamef  system/repl/debug.scm
 
	 	(	' 	$	R 		X 		` 		c 	(	i 		m 		s 		{ 		} 		} 	  	  	&  	  	  	#  	  	  	  	  	
  	  	
  	  	
  	  	-  	(
 	 	" 	' 	1 	4 	9 	? 	@ 	^ 	b 	h 	y 	 ,	yg  widthS	g  full?S	g  forward?S	g  countS	g  	for-trap?S	   g  nameg  print-frames C>Rxyz{$} 	  hp      ]4L 4 554 5$  "  4544 54 5$  "  >  "  G  L4 56          g  binding
		l g  x		l g  var		*	l  g  filenamef  system/repl/debug.scm
 		 		 	.	 		 	
	 		 		$ 	8	* 	
	- 		2 		3 		: 		C 		G 		J 	1	U 		b 	!	l 	 		l   Cu 
  hx   @  ]4 545$  ]45$  "  45 45 4>  "  G  4 O 4	 5>  "  G  C6  8      g  frame
		w g  proc			w g  t			3 g  mod		3	s g  mod*		:	s  g  filenamef  system/repl/debug.scm
 
	 			 		 		 		 		 		, 	.	3 		6 		: 		= 	
	Q 	
	] 		h 	
	w 	 		w  g  nameg  
frame->module C?R h`   G  ]!4 545
$  ?"  &$  45""  
4 
5""   C  ?      g  stack
		^ g  len			^ g  v			^ g  i		 	F g  frame		 	F  g  filenamef  system/repl/debug.scm
 
	 			 		 		 		 		 		  		% 		) 	
	0 		3 		4 		B 		F 		H 		W 	 		^  g  nameg  
stack->vector C@R@  h0      - 1 3 44 
5?$  6C              g  stack
			) g  args			) g  narrowed			)  g  filenamef  system/repl/debug.scm
 
	
 		
 	$	 		 		  		& 		( 	 				)
  g  nameg  narrow-stack->vector CARA      h8      ]	[$  	["  4 5

$  "  6              g  frame
		1 g  tag		1  g  filenamef  system/repl/debug.scm
 
	 		
 	
	 		 		 		) 		1 	 			1  g  nameg  frame->stack-vector CBRC       g  m
		, g  	set-width
  g  filenamef  system/repl/debug.scm		
	:	9
	A		A		@
	P
		X

(	d
	x
 
k 
* 
X 
v 
 	x
   C6 
